KashierErrorCode enum

Error codes returned by the Kashier SDK.

Inheritance
Available extensions

Values

sessionExpired → const KashierErrorCode

The payment session has expired.

sessionNotFound → const KashierErrorCode

The payment session was not found.

applePayNotAvailable → const KashierErrorCode

Apple Pay is not available on this device.

userCancelled → const KashierErrorCode

The user cancelled the payment.

validationFailed → const KashierErrorCode

Merchant validation with Apple Pay failed.

applePayConfigError → const KashierErrorCode

Apple Pay merchant configuration error (wrong merchant ID, missing certificate, or running on Simulator).

merchantValidationFailed → const KashierErrorCode

Merchant validation failed during the Apple Pay session.

tokenProcessingFailed → const KashierErrorCode

Processing the Apple Pay token failed.

paymentDeclined → const KashierErrorCode

The payment was declined by the issuer/processor.

authorizationFailed → const KashierErrorCode

Authorization/authentication failed (403, invalid hash, etc.).

networkError → const KashierErrorCode

A network error occurred.

paymentTimeout → const KashierErrorCode

Polling exceeded the maximum duration waiting for wallet payment.

walletInitFailed → const KashierErrorCode

The wallet INITIATE_R2P API call failed.

cardRetrievalFailed → const KashierErrorCode

Failed to retrieve saved cards from the API.

cardDeletionFailed → const KashierErrorCode

Failed to delete a saved card.

invalidCardDetails → const KashierErrorCode

The card details provided are invalid.

authenticationFailed → const KashierErrorCode

3DS authentication failed.

unknownError → const KashierErrorCode

An unknown error occurred.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KashierErrorCode>
A constant List of the values in this enum, in order of their declaration.