KashierMode enum
Environment mode for Kashier SDK.
Controls which Kashier API environment is used for all requests.
Values
- test → const KashierMode
-
Test environment — use for development and testing.
- live → const KashierMode
-
Live environment — use for production payments.
Properties
- baseUrl → String
-
The base URL for the Kashier API in this mode.
no setter
- fepBaseUrl → String
-
The base URL for the Kashier FEP (payment processing) in this mode.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
KashierMode> - A constant List of the values in this enum, in order of their declaration.