KashierPaymentError class
Represents an error that occurred during a Kashier payment.
Constructors
- KashierPaymentError({required KashierErrorCode code, required String message, String? messageAr, String? responseCode, Object? details})
-
const
-
KashierPaymentError.fromApiResponse(Map<
String, dynamic> body, {required int statusCode}) -
Creates an error from a Kashier API error response body.
factory
- KashierPaymentError.fromCode(KashierErrorCode code, {String? message, String? messageAr, String? responseCode, Object? details})
-
Creates an error from an error code with a default message.
factory
Properties
- code → KashierErrorCode
-
The error code identifying the type of error.
final
- details → Object?
-
Optional additional details about the error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable error message in English.
final
- messageAr → String?
-
A human-readable error message in Arabic, if available.
final
- responseCode → String?
-
The issuer/processor response code (e.g., "57"), if available.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited